summaryrefslogtreecommitdiffstats
path: root/commands
diff options
context:
space:
mode:
authorJan Pokorný <jpokorny@redhat.com>2014-03-07 00:38:11 +0100
committerJan Pokorný <jpokorny@redhat.com>2014-03-07 00:39:19 +0100
commitd0bd4d86500d91916d90ec330e0194a034f26dc6 (patch)
tree1c7c45caa3c51cfedf02c63d288c7db3f2c4cd8f /commands
parenta9ba9bfb5e82d6101ab878249cce5d009f6c767a (diff)
downloadclufter-d0bd4d86500d91916d90ec330e0194a034f26dc6.tar.gz
clufter-d0bd4d86500d91916d90ec330e0194a034f26dc6.tar.xz
clufter-d0bd4d86500d91916d90ec330e0194a034f26dc6.zip
commands/ccs2pcs: [ccs]flatiron[xml] -> pcmk + reformat
Signed-off-by: Jan Pokorný <jpokorny@redhat.com>
Diffstat (limited to 'commands')
-rw-r--r--commands/ccs2pcs.py38
1 files changed, 26 insertions, 12 deletions
diff --git a/commands/ccs2pcs.py b/commands/ccs2pcs.py
index 1df9630..c99cad0 100644
--- a/commands/ccs2pcs.py
+++ b/commands/ccs2pcs.py
@@ -9,13 +9,13 @@ from ..command import Command, CommandAlias
@Command.deco(('ccs2ccsflat',
- 'ccsflat2pcs',
- 'ccs2ccslight',
- ('ccs2flatironxml',
- 'xml2simpleconfig')))
+ 'ccsflat2pcs',
+ 'ccs2ccs-pcmk',
+ ('ccs2flatironxml',
+ 'xml2simpleconfig')))
def ccs2pcs_flatiron(cmd_ctxt,
input='/etc/cluster/cluster.conf',
- ccsflatiron='./cluster.conf',
+ ccs_pcmk='./cluster.conf',
cib='./cib.xml',
coro='./corosync.conf',
nocheck=False):
@@ -28,21 +28,28 @@ def ccs2pcs_flatiron(cmd_ctxt,
Options:
input input CMAN-based cluster configuration file
ccsflatiron output reduced CMAN configuration
cib output pacemaker-based configuration file
coro output Corosync configuration file
nocheck do not validate any step (even if self-checks present)
"""
#cmd_ctxt.filter()['validate'] = not nocheck
#cmd_ctxt.filter('ccs2ccsflat')['validate'] = not nocheck
- return ('file', input), \
- ('file', ccsflatiron), (('file', cib), (('file', coro), ))
+ return (
+ ('file', input), (
+ ('file', ccs_pcmk),
+ ('file', cib),
+ (
+ ('file', coro),
+ )
+ )
+ )
@Command.deco(('ccs2ccsflat',
- 'ccsflat2pcs',
- ('ccs2needlexml',
- 'xml2simpleconfig')))
+ 'ccsflat2pcs',
+ ('ccs2needlexml',
+ 'xml2simpleconfig')))
def ccs2pcs_needle(cmd_ctxt,
input='/etc/cluster/cluster.conf',
cib='./cib.xml',
@@ -62,7 +69,14 @@ def ccs2pcs_needle(cmd_ctxt,
"""
#cmd_ctxt.filter()['validate'] = not nocheck
#cmd_ctxt.filter('ccs2ccsflat')['validate'] = not nocheck
- return ('file', input), (('file', cib), (('file', coro), ))
+ return (
+ ('file', input), (
+ ('file', cib),
+ (
+ ('file', coro),
+ )
+ )
+ )
@CommandAlias.deco
@@ -28,21 +28,28 @@ def ccs2pcs_flatiron(cmd_ctxt,
Options:
input input CMAN-based cluster configuration file
- ccsflatiron output reduced CMAN configuration
+ ccs_pcmk output reduced CMAN configuration
cib output pacemaker-based configuration file
coro output Corosync configuration file